OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Hiljutised staatused",
    "In a meeting" : "Koosolekul",
    "Out sick" : "Haige",
    "Vacationing" : "Puhkusel",
    "Working remotely" : "Kaugtööl",
    "User status" : "Kasutaja staatus",
    "Clear status after" : "Tühjenda staatus pärast",
    "Emoji for your status message" : "Staatuse teate emoji",
    "What is your status?" : "Mis on su staatus?",
    "Predefined statuses" : "Eeldefineeritud staatused",
    "Status message" : "Staatuse teade",
    "Clear status message" : "Tühjenda staatuseteade",
    "Don't clear" : "Ära tühjenda",
    "Today" : "Täna",
    "This week" : "Käesolev nädal",
    "Online" : "Online",
    "Away" : "Eemal",
    "Do not disturb" : "Mitte segada",
    "Invisible" : "Nähtamatu",
    "Offline" : "Offline",
    "30 minutes" : "30 minutit",
    "1 hour" : "1 tund",
    "4 hours" : "4 tundi",
    "Mute all notifications" : "Vaigista kõik teavituse",
    "View profile" : "Vaata profiili"
},
"nplurals=2; plural=(n != 1);");
